@@ -106,6 +106,8 @@ struct _CcDisplayPanel
 
   GListStore     *primary_display_list;
   GtkListStore   *output_selection_list;
+  GtkWidget      *output_frame;
+  GtkWidget      *display_settings_disabled_group;
 
   GtkWidget      *arrangement_frame;
   GtkAlignment   *arrangement_bin;
@@ -473,6 +475,7 @@ static void
 cc_display_panel_dispose (GObject *object)
 {
   CcDisplayPanel *self = CC_DISPLAY_PANEL (object);
+  GtkWidget *toplevel = cc_shell_get_toplevel (cc_panel_get_shell (CC_PANEL (self)));
 
   reset_titlebar (CC_DISPLAY_PANEL (object));
 
@@ -495,6 +498,8 @@ cc_display_panel_dispose (GObject *object)
 
   g_clear_pointer ((GtkWidget **) &self->night_light_dialog, gtk_widget_destroy);
 
+  g_signal_handlers_disconnect_by_data (toplevel, self);
+
   G_OBJECT_CLASS (cc_display_panel_parent_class)->dispose (object);
 }
 
@@ -666,12 +671,26 @@ on_primary_display_selected_index_changed_cb (CcDisplayPanel *panel)
   update_apply_button (panel);
 }
 
+static void
+on_toplevel_folded (CcDisplayPanel *panel, GParamSpec *pspec, GtkWidget *toplevel)
+{
+  gboolean folded;
+
+  g_object_get (toplevel, "folded", &folded, NULL);
+  cc_display_settings_refresh_layout (panel->settings, folded);
+}
+
 static void
 cc_display_panel_constructed (GObject *object)
 {
+  GtkWidget *toplevel = cc_shell_get_toplevel (cc_panel_get_shell (CC_PANEL (object)));
+
   g_signal_connect_object (cc_panel_get_shell (CC_PANEL (object)), "notify::active-panel",
                            G_CALLBACK (active_panel_changed), object, G_CONNECT_SWAPPED);
 
+  g_signal_connect_swapped (toplevel, "notify::folded", G_CALLBACK (on_toplevel_folded), object);
+  on_toplevel_folded (CC_DISPLAY_PANEL (object), NULL, toplevel);
+
   G_OBJECT_CLASS (cc_display_panel_parent_class)->constructed (object);
 }
 
@@ -884,6 +903,7 @@ set_current_output (CcDisplayPanel   *panel,
 {
   GtkTreeIter iter;
   gboolean changed;
+  gboolean lockdown;
 
   /* Note, this function is also called if the internal UI needs updating after a rebuild. */
   changed = (output != panel->current_output);
@@ -935,6 +955,12 @@ set_current_output (CcDisplayPanel   *panel,
     {
       cc_display_settings_set_selected_output (panel->settings, panel->current_output);
       cc_display_arrangement_set_selected_output (panel->arrangement, panel->current_output);
+
+      if (cc_has_fractional_key())
+        {
+          lockdown=cc_display_config_get_fractional_scaling (panel->current_config);
+          gtk_widget_set_sensitive(panel->automatic_screen_lock_switch, !lockdown);
+        }
     }
 
   panel->rebuilding_counter--;
@@ -947,6 +973,14 @@ rebuild_ui (CcDisplayPanel *panel)
   GList *outputs, *l;
   CcDisplayConfigType type;
 
+  if (!cc_display_config_manager_get_apply_allowed (panel->manager))
+    {
+      gtk_widget_set_visible (panel->display_settings_disabled_group, TRUE);
+      gtk_widget_set_visible (panel->config_type_switcher_frame, FALSE);
+      gtk_widget_set_visible (panel->arrangement_frame, FALSE);
+      return;
+    }
+
   panel->rebuilding_counter++;
 
   g_list_store_remove_all (panel->primary_display_list);
@@ -958,6 +992,8 @@ rebuild_ui (CcDisplayPanel *panel)
       return;
     }
 
+  gtk_widget_set_visible (panel->display_settings_disabled_group, FALSE);
+
   n_active_outputs = 0;
   n_usable_outputs = 0;
   outputs = cc_display_config_get_ui_sorted_monitors (panel->current_config);
@@ -1093,7 +1129,7 @@ reset_current_config (CcDisplayPanel *panel)
 
   if (!current)
     return;
-  
+
   cc_display_config_set_minimum_size (current, MINIMUM_WIDTH, MINIMUM_HEIGHT);
   panel->current_config = current;
 
@@ -1482,8 +1518,10 @@ cc_display_panel_class_init (CcDisplayPanelClass *klass)
   gtk_widget_class_bind_template_child (widget_class, CcDisplayPanel, config_type_single);
   gtk_widget_class_bind_template_child (widget_class, CcDisplayPanel, current_output_label);
   gtk_widget_class_bind_template_child (widget_class, CcDisplayPanel, display_settings_frame);
+  gtk_widget_class_bind_template_child (widget_class, CcDisplayPanel, display_settings_disabled_group);
   gtk_widget_class_bind_template_child (widget_class, CcDisplayPanel, multi_selection_box);
   gtk_widget_class_bind_template_child (widget_class, CcDisplayPanel, night_light_page);
+  gtk_widget_class_bind_template_child (widget_class, CcDisplayPanel, output_frame);
   gtk_widget_class_bind_template_child (widget_class, CcDisplayPanel, output_enabled_switch);
   gtk_widget_class_bind_template_child (widget_class, CcDisplayPanel, output_selection_combo);
   gtk_widget_class_bind_template_child (widget_class, CcDisplayPanel, output_selection_stack);
